@@ -6,7 +6,7 @@
 #' Application Default Credentials (ADC). The hope is to make auth "just work"
 #' for someone working on Google-provided infrastructure or who has used Google
 #' tooling to get started, such as the [`gcloud` command line
-#' tool](https://cloud.google.com/sdk/gcloud).
+#' tool](https://docs.cloud.google.com/sdk/gcloud).
 #'
 #' A sequence of paths is consulted, which we describe here, with some abuse of
 #' notation. ALL_CAPS represents the value of an environment variable and `%||%`
@@ -32,9 +32,9 @@
 #'
 #' @seealso
 
-#' * <https://cloud.google.com/docs/authentication#adc>
+#' * <https://docs.cloud.google.com/docs/authentication>
 
-#' * <https://cloud.google.com/sdk/docs/>
+#' * <https://docs.cloud.google.com/sdk/docs>
 
 #' @return An [`httr::TokenServiceAccount`][httr::Token-class], a [`WifToken`],
 #'   an [`httr::Token2.0`][httr::Token-class] or `NULL`.
@@ -71,7 +71,11 @@ credentials_app_default <- function(scopes = NULL, ..., subject = NULL) {
       return(NULL)
     }
     gargle_debug("ADC cred type: {.val authorized_user}")
-    app <- httr::oauth_app("google", info$client_id, secret = info$client_secret)
+    app <- httr::oauth_app(
+      "google",
+      info$client_id,
+      secret = info$client_secret
+    )
     scope <- "https://www.googleapis.com/auth/cloud.platform"
     token <- httr::Token2.0$new(
       endpoint = gargle_oauth_endpoint(),
